@@ -592,7 +592,8 @@ WORD quotient_f(int na, WORD *fp) /* fixnumݡȤƤޤ */
 #endif
 #ifndef NO_BIGNUM
       if(t==BIGNUM){
-	if(flag==0){flag=1; continue;}
+	if(flag==0)flag=1;
+	continue;
       }
 #endif
       nofixerr(a);
@@ -658,7 +659,8 @@ WORD remainder_f(int na, WORD *fp)
 {
   WORD a,b,c;
   int t;
-
+  double fval;
+ 
   if(na!=2)parerr();
   if((t=tag(a=ag(1)))==OTHERS){
     t=otag(a);
@@ -667,17 +669,21 @@ WORD remainder_f(int na, WORD *fp)
       if((t=tag(b=ag(0)))==OTHERS){
 	if(otag(b)==FLONUM){
 	  if(floval(b)==0.0)zerodiverr(fp);
-	  return alflonum(fmod(floval(a),floval(b)),fp);
+	  fval=fmod(floval(a),floval(b));
+	  return alflonum(fval,fp);
 	}
 #ifndef NO_BIGNUM
-	else if(otag(b)==BIGNUM)
-	  return alflonum(fmod(floval(a),bigtoflo(b)),fp);
+	else if(otag(b)==BIGNUM){
+	  fval=fmod(floval(a),bigtoflo(b));
+	  return alflonum(fval,fp);
+	}
 #endif
 	else nosymerr(b);
       }
       else if(t!=FIXNUM)nofixerr(b);
       if((t=fixtoi(b))==0)zerodiverr(fp);
-      return alflonum(fmod(floval(a),(double)t),fp);
+      fval=fmod(floval(a),(double)t);
+      return alflonum(fval,fp);
     }
 #endif /* NO_FLONUM */
 #ifndef NO_BIGNUM
@@ -686,7 +692,8 @@ WORD remainder_f(int na, WORD *fp)
 #ifndef NO_FLONUM
 	if(otag(b)==FLONUM){
 	  if(floval(b)==0.0)zerodiverr(fp);
-	  return alflonum(fmod(bigtoflo(a),floval(b)),fp);
+	  fval=fmod(bigtoflo(a),floval(b));
+	  return alflonum(fval,fp);
 	}
 #endif /* NO_FLONUM */
 	else if(otag(b)==BIGNUM)
@@ -707,7 +714,8 @@ WORD remainder_f(int na, WORD *fp)
 #ifndef NO_FLONUM
     if(t==FLONUM){
       if(floval(b)==0.0)zerodiverr(fp);
-      return alflonum(fmod((double)fixtoi(a),floval(b)),fp);
+      fval=fmod((double)fixtoi(a),floval(b));
+      return alflonum(fval,fp);
     }
 #endif
 
